Index: src/sksl/ir/SkSLVarDeclarationStatement.h |
diff --git a/src/sksl/ir/SkSLVarDeclarationStatement.h b/src/sksl/ir/SkSLVarDeclarationStatement.h |
index e81c0ac3ecab97cb09a28a3a565de547a3394e00..59d37ab9158945b78cd7ffda6b065224e286eb9e 100644 |
--- a/src/sksl/ir/SkSLVarDeclarationStatement.h |
+++ b/src/sksl/ir/SkSLVarDeclarationStatement.h |
@@ -14,18 +14,18 @@ |
namespace SkSL { |
/** |
* A variable declaration appearing as a statement within a function. |
*/ |
-struct VarDeclarationStatement : public Statement { |
- VarDeclarationStatement(std::unique_ptr<VarDeclaration> decl) |
- : INHERITED(decl->fPosition, kVarDeclaration_Kind) |
+struct VarDeclarationsStatement : public Statement { |
+ VarDeclarationsStatement(std::unique_ptr<VarDeclarations> decl) |
+ : INHERITED(decl->fPosition, kVarDeclarations_Kind) |
, fDeclaration(std::move(decl)) {} |
std::string description() const override { |
return fDeclaration->description(); |
} |
- const std::shared_ptr<VarDeclaration> fDeclaration; |
+ const std::shared_ptr<VarDeclarations> fDeclaration; |
typedef Statement INHERITED; |
}; |
@@ -14,18 +14,18 @@ |
namespace SkSL { |
/** |
- * A variable declaration appearing as a statement within a function. |
+ * One or more variable declarations appearing as a statement within a function. |
*/ |